"use strict";

const e = React.createElement;

class MethodsResults extends React.Component {
  constructor(props) {
    super(props);
  }
  render() {
    let usedMethods = getFromStorage(["methods"]);
    let negativeThoughts = getFromStorage(["negativeThoughts"]);
    return (
      <div className="print-section">
        <h2>Methods I used on some thoughts</h2>
        <table className="print-feelings-table">
          <thead>
            <tr>
              <th className="reframed-item">Thought</th>
              <th>Method and results</th>
            </tr>
          </thead>
          <tbody>
            {Object.keys(usedMethods).map((thoughtIndex) => {
              let usedMethodsForThought = usedMethods[thoughtIndex];
              return (
                <tr className="print-feelings-row" key={thoughtIndex}>
                  <td className="reframed-item">
                    {negativeThoughts[thoughtIndex]}
                  </td>
                  <td>
                    <ul className="print-used-methods">
                      {Object.keys(usedMethodsForThought).map(
                        (methodShortname) => {
                          let thisUsedMethod =
                            usedMethodsForThought[methodShortname];
                          let whoWonString =
                            thisUsedMethod["whoWon"] == "negative"
                              ? "The negative thought"
                              : "The new thought";
                          return (
                            <li key={methodShortname} className="print-method">
                              <p>
                                <b>Method:</b>{" "}
                                {getTechniqueLongName(methodShortname)}
                              </p>
                              <p>
                                <b>Your response:</b> {thisUsedMethod["result"]}
                              </p>
                              <p>
                                <b>Who whon?</b> {whoWonString}
                              </p>
                              <p>
                                <b>How much do I believe the new thought?</b>{" "}
                                {thisUsedMethod["newThoughtBeliefLevel"]} %
                              </p>
                              <p>
                                <b>
                                  How much do I believe the old thought after
                                  using this method?
                                </b>{" "}
                                {thisUsedMethod["oldThoughtNewBeliefLevel"]} %
                              </p>
                            </li>
                          );
                        }
                      )}
                    </ul>
                  </td>
                </tr>
              );
            })}
          </tbody>
        </table>
      </div>
    );
  }
}

class PositiveReframe extends React.Component {
  constructor(props) {
    super(props);
  }
  render() {
    let allFeelings = getFromStorage(["feelings"]);
    let allThoughts = getFromStorage(["negativeThoughts"]);
    let positiveReframe = getFromStorage(["positiveReframe"]);
    return (
      <div className="print-section">
        <h2>Positive reframe of thoughts and feelings</h2>
        <table className="print-feelings-table">
          <thead>
            <tr>
              <th className="reframed-item">Thought or feeling</th>
              <th>Positive reframe</th>
            </tr>
          </thead>
          <tbody>
            {Object.keys(positiveReframe.feelings).map((feelingIndex) => {
              if (allFeelings[feelingIndex].length < 1) {
                return "";
              }
              return (
                <tr className="print-feelings-row" key={feelingIndex}>
                  <td className="reframed-item">
                    {allFeelings[feelingIndex].map((feeling, i) => {
                      return (
                        <span key={i} className="print-reframe-feeling">
                          {feeling}
                        </span>
                      );
                    })}
                  </td>
                  <td>
                    <ul>
                      {positiveReframe.feelings[feelingIndex].map(
                        (reframe, i) => {
                          return <li key={i}>{reframe}</li>;
                        }
                      )}
                    </ul>
                  </td>
                </tr>
              );
            })}
            {Object.keys(positiveReframe.thoughts).map((thoughtIndex) => {
              return (
                <tr className="print-feelings-row" key={thoughtIndex}>
                  <td className="reframed-item">{allThoughts[thoughtIndex]}</td>
                  <td>
                    <ul>
                      {positiveReframe.thoughts[thoughtIndex].map(
                        (reframe, i) => {
                          return <li key={i}>{reframe}</li>;
                        }
                      )}
                    </ul>
                  </td>
                </tr>
              );
            })}
          </tbody>
        </table>
      </div>
    );
  }
}

class Thoughts extends React.Component {
  constructor(props) {
    super(props);
  }
  render() {
    return (
      <div className="print-section">
        <h2>Thoughts I had in this moment</h2>
        {getFromStorage(["negativeThoughts"]).map((thought, i) => {
          return (
            <div key={i} className="print-textbox">
              {thought}
            </div>
          );
        })}
      </div>
    );
  }
}

class Feelings extends React.Component {
  constructor(props) {
    super(props);
  }
  render() {
    // TODO: put this and other things in props somehow.
    let allFeelings = getFromStorage(["feelings"]);
    let allFeelingsRatings = getFromStorage(["feelingsRatings"]);
    let allFeelingsRatingsGoal = getFromStorage(["feelingsRatingsGoal"]);
    return (
      <div className="print-section">
        <h2>Feelings I had in this moment</h2>
        <table className="print-feelings-table">
          <thead>
            <tr>
              <th>Feeling</th>
              <th>Original % (0-100)</th>
              <th>Goal % (0-100)</th>
            </tr>
          </thead>
          <tbody>
            {feelingsList.map((feelingsCategory, feelingsCatIndex) => {
              return (
                <tr className="print-feelings-row" key={feelingsCatIndex}>
                  <td>
                    {feelingsCategory.map((feeling) => {
                      let checked =
                        allFeelings.hasOwnProperty(feelingsCatIndex) &&
                        allFeelings[feelingsCatIndex].includes(feeling);
                      let maybeCircledClass = checked
                        ? "print-feeling-circled"
                        : "";
                      let feelingClass = "print-feeling " + maybeCircledClass;
                      return (
                        <span className={feelingClass} key={feeling}>
                          {feeling}
                        </span>
                      );
                    })}
                  </td>
                  <td>
                    <span
                      className="print-feelingRating"
                      name={feelingsCatIndex}
                    >
                      {allFeelingsRatings[feelingsCatIndex]}
                    </span>
                  </td>
                  <td>
                    <span
                      className="print-feelingRatingGoal"
                      name={feelingsCatIndex}
                    >
                      {allFeelingsRatingsGoal[feelingsCatIndex]}
                    </span>
                  </td>
                </tr>
              );
            })}
          </tbody>
        </table>
      </div>
    );
  }
}

// NOTE: does this even need to be React... ?
class MainContainer extends React.Component {
  constructor(props) {
    super(props);
  }

  render() {
    // TODO: include... everything!
    // * moment => done!
    // * feelings => done!
    // * negative thoughts => done!
    // * positive reframe => done!
    // * magic dial on feelings => done!
    // * methods tried => done!
    // * ratings of methods tried => done!

    return (
      <div>
        <h1 className="print-title">My Feeling Great Worksheet</h1>
        <hr />
        <div className="print-section">
          <h2>Moment in time I chose to work on</h2>
          <div className="print-textbox">{localStorage["instance"]}</div>
        </div>
        <Feelings />
        <Thoughts />
        <PositiveReframe />
        <MethodsResults />
      </div>
    );
  }
}

// Initialize React.
const domContainer = document.querySelector("#react_container");
const root = ReactDOM.createRoot(domContainer);
root.render(e(MainContainer));
